# pixiv-bulk-downloader

- Pixiv Bulk Downloader

## Feature

- Download
  - works of following users
    - SAVE: `$HOME/pbd/following`
  - bookmarked works
    - SAVE: `$HOME/pbd/bookmarks`

## Try

```bash
# pip 3.x
pip install pixiv-bulk-downloader
# run
pbd
[+]ID is mail address, userid, account name.
[+]ID:
[+]Password:
get_all_following_works? [yn]:
get_all_bookmarked_works? [yn]:
```
